# Unit 2: Biology

## Cellular Biology
A person contains roughly 100 trillion cells
- Cells are roughly 20 `μm` (micrometre, 10<sup>-6</sup> m), around 250 cells / cm

## Cell Theory
1. All living things are composed of cells 
2. Cells are the basic units of living organisms
3. All cells came from pre-existing cells

## Eukaryotic versus Prokaryotic Cells
`Prokaryotic cell`: Meaning before/lacking nucleus

`Eukaryotic cell`: Means complete nucleus

|Factors|Prokaryotic|Eukaryotic|
|:-----------|:----------|:---------|
|DNA|In nucleoid region|Usually in membrane-bound nucleus|
|Size|Usually smaller|Usually larger|
|Organelles|Not membrane-bound, smaller|Membrane-bound, more complex|
|Organization|Usually singlecelled|Often form multicellular organisms|
|Metabolism|May not need oxygen|Usually need oxygen|

## Cellular Organelles

### Business Analogy

| In a business | In a cell | 
| ------------- | --------- |
| Building      | Cytoplasm & Cytoskeleton |
| Department Head | Organelles |
| Boss          | DNA |
| Workers       | Ribosomes & Enzymes |
| Waste management | Lysosomes |
| Storage       | Vacuoles | 
| Powerhouse    | Chloroplasts & Mitochondria |
| Security gate | Cell membrane controls entrance and exit from the cell |
| Transportation Department | IMPORT: Cell membranes and vesicles, INTERNAL: Endoplasmic reticulum & vesicles, EXPORT: Golgi apparatus, vesicles, and cell membrane |


### Cell Membrane
- Controls what substances enter/leave the cell selectively via various receptors/osmosis
    - Allows nutrients to enter
    - Allows waste products to leave
- Surrounds and holds other organelles in cell
- Interact with outside chemicals (e.g., hormones) 

### Nucleus
- Holds deoxyribonucleic acid (DNA) in form of `chromatin`
    - DNA is a double helix that make genes
        - `Genes` are a complete set of instructions to make a complete product (typically proteins)
        - `Genes`: one of the many sets of instructions, in your DNA, found on a **chromosome**, for making a functional product (mostly proteins)
    - `Chromatin` is DNA wrapped tightly in protein
- `Chromosomes` are even more tightly wrapped chromatin used in cell division only
- Surrounded by a double membrane
- Substances enter and exit the nucleus via nuclear pores
- Messenger RNA (mRNA) is encoded from DNA and sent to `ribosomes` to produce proteins


### Nucleolus
 - Dense region of DNA located in the nucleus
 - This area of DNA is specially for ribosomal DNA (rDNA), or DNA used to make ribosomes
 - Produce "large" and "small" subunits of ribosomes, which either form complete ribosomes in cytosol or mix with endoplasmic reticulum, forming rough endoplasmic reticulum (RER)
 - Is *not* surrounded by a membrane, literally is just same as rest of nucleus but denser

### Cytoplasm & Cytosol
 - `Cytosol` is the fluid cells contain
 - **All organelles** are suspended in `cytosol`
 - `Cytoplasm` is the `cytosol` along with everything in a cell, excluding the nucleus

## Endoplasmic Reticulum
- The endoplasmic reticulum is a network of tubules and flattened sacs with a "rough" appearance because of the presence of `ribosomes` on the surface
- Network of tubules and flattened sacs
- **Transport** proteins via cytoskeleton in vesicles

## Rouch Endoplasmic Reticulum
- Appears "rough" due to the `ribosomes` attached to its outer surface
- Located directly adjacent and attached to nucleus
- Located next to `Golgi apparatus`
- `Ribosomes` in rough ER synthesize proteins
    - Only specific proteins are synthesized by ribosomes of rough ER
    - Proteins synthesized in `ribosomes` of rough ER are always sent to either `Golgi apparatus` via `vesicles` or stay in `rough ER`
    - `Ribosomes` attach to and leave the `rough ER` regularly
    - About half the cell's proteins are produced here
- **Modify, fold, and fix proteins**

### Functions
- **Protein synthesis**
    - About half of the cell's proteins are made here, by the `ribosomes`
- **Protein movement**
    - Proteins are transported by vesicles throught the cell to other organelles, like the `golgi apparatus`
- **Protein "Proof-Reading"**
    - pre-existing proteins can enter the `rough-ER` for **modification**

## Smooth ER
- Does not synthesize proteins
- Appears "smooth" due to lack of `ribosomes`
- Located directly adjacent and attached to nucleus
- Synthesizes lipids (fats, e.g., cholesterol)
- Metabolises carbohydrates

## Golgi Apparatus (Golgi Complex)
- **Receives, modifies and transports** proteins that were produced by the `rough-E.R`
- **Packages** proteins into `vesicles` and sends them `cell membrane` for export

## Lysosome
- `White blood` cell uses the cytoskeleton to reach out and swallow up a bacterium, then uses `lysosomes` to break it down
- Spherical vesicle that contains `enzymes`
- Digests and kills foreign matter which is then excreted
- Digests and breaks down old and unused material to be recycled
- Digests and breaks down old or non-functional organelles as needed
- Only plays a very minor role in cell suicide (`apoptosis`)
- If lysosome does rupture (accidentally) everything dies

### Functions
- **Digestion**
    - Food or foriegn matter (invaders) are swallowed up and executed
- **Recycling**
    - When an organelle "dies" `lysosomes` will recycle the dea material back into raw materials cellular suicide
- **Cellular suicicde**
    - This is not good for the cell (obviously, but it is good for us. (E.g reasons why most of us don't have web feet/hands)

## Midtochondria
 - **Plural is "mitochondria"**
 - Contains an inner and outer membrane
 - Processes glucose + oxygen gas to form carbon dioxide + adenosine triphosphate (ATP)
    - ATP allows proteins to do things (e.g., spend 1 ATP break 1 molecule)
    - ATP cannot be stored
 - Mitochondria have their own DNA

## Cytoskeleton
- The cytosekleton **is** the skeleton of the cell, found in the `cytosol`, made up of protein.
- The cytoskeleton is also like the muscular system, able to change teh sahpe of cells in a flash
- Made of protein filaments
- Maintains and changes cell structure, much like a human skeleton + muscular system
    - Moves cells
- Chemicals can travel along cytoskeleton, e.g., organelles, vesicles, etc.

## Organelles Specific To Animal Cells
1. centrioles and centrosomes
2. lysosomes

### Centrioles and Centrosomes
- Involved in the process of cell division for animal cells, plant cells **DO NOT** use centrioles
 - Made of same protein as cytoskeleton
 - A centrosome is a pair of centrioles
 - Very important to cell division
    - Split chromosomes apart after DNA has been replicated into daughter cells
    - Helps regulate cell division
 - Create cilia and flagella (e.g., small hair-like things that swipe dirt out of lungs and tails of sperm, respectively)

### Lysosomes
- Present in all animal cells but not present in the cells of most plants

## Organelles Specific To Plant Cells
1. Cell wall
2. Chloroplast
3. Central Vacuole

### Cell wall
- Provides structure and prevents cell rupture
- Can be tough, flexible, and/or rigid
- Permeable to small molecules
- Made of cellulose (type of sugar)
- Also present in most bacteria, fungi, and protists

### Chloroplast
- The `solar panel` of the plant cell.
- Conducts photosynthesis
- All chlorophyll is located in chloroplasts
- Looks green

### Central Vacuole
- Extremely large, may take up to 90% of volume in cell
- Contains water
- Maintains `turgor` pressure against cell wall (pushes against cell wall in all directions)
- **Provides the cell with shape**











